# A debhelper build system class for handling pkg-js-autopkgtest test.
#
# Copyright: 2019, Xavier Guimard <yadd@debian.org>
# License: GPL-2+

package Debian::Debhelper::Buildsystem::nodejs;

use strict;
use warnings;
use Debian::Debhelper::Dh_Lib;
use parent qw(Debian::Debhelper::Buildsystem);
use File::Temp;
use JSON;

sub DESCRIPTION {
    "pkg-js-autopkgtest test";
}

sub new {
    my $class = shift;
    return $class->SUPER::new(@_);
}

sub check_auto_buildable {
    my $self = shift;
    if ( -e 'package.json' ) {
        return 1;
    }
    return 0;
}

sub test {
    my $self = shift;
    my $res;
    open F, $self->get_build_rel2sourcedir('package.json');
    my $content = join '', <F>;
    close F;
    eval { $content = JSON::decode_json($content) };
    if ($@) {
        die "Malfored package.json: $@";
    }
    if ( $content->{module} ) {
        my $fh = File::Temp->new( SUFFIX => '.js' );
        open F, '>', $fh or die $!;
        print F "import foo from '$content->{name}'";
        close F;
        $self->doit_in_sourcedir( 'rollup', $fh, '-f', 'umd', '-o',
            "$fh-new.js", );
        unlink $fh, "$fh-new.js";
    }
    if ( -e 'debian/tests/pkg-js/test' ) {
        $res = $self->doit_in_builddir( '/bin/sh', '-e',
            'debian/tests/pkg-js/test' );
    }
    else {
        $res = $self->doit_in_builddir( '/usr/bin/node', '-e', 'require(".")' );
    }
}

1;
